# API Reference

```{eval-rst}
.. autofunction:: emolib.EmoScores.set_baseline
```
```{eval-rst}
.. autofunction:: emolib.EmoScores.emotions
```
```{eval-rst}
.. autofunction:: emolib.EmoScores.zscores
```
```{eval-rst}
.. autofunction:: emolib.EmoScores.formamentis_network
```
```{eval-rst}
.. autofunction:: emolib.EmoScores.draw_formamentis
```
```{eval-rst}
.. autofunction:: emolib.EmoScores.draw_statistically_significant_emotions
```
```{eval-rst}
.. autofunction:: emolib.EmoScores.draw_formamentis_flower
```
```{eval-rst}
.. autofunction:: emolib.EmoScores.draw_plutchik
```


